@@ -11,3 +11,8 @@ register(
     entry_point='sorting_gym.envs.bubblesort:BasicNeuralSortInterfaceEnv'
 )
 
+register(
+    id='FunctionalNeuralSortInterfaceEnv-v0',
+    entry_point='sorting_gym.envs.functional_neural_sort_interface:FunctionalNeuralSortInterfaceEnv'
+)
+
